@@ -12,6 +12,7 @@
 #include "journalview.h"
 #include "journalframe.h"
 
+#include <Akonadi/CalendarUtils>
 #include <CalendarSupport/Utils>
 
 #include "calendarview_debug.h"
@@ -38,11 +39,9 @@ JournalView::JournalView(QWidget *parent)
     installEventFilter(this);
 }
 
-JournalView::~JournalView()
-{
-}
+JournalView::~JournalView() = default;
 
-void JournalView::appendJournal(const Akonadi::Item &journal, const QDate &dt)
+void JournalView::appendJournal(const Akonadi::Item &journal, QDate dt)
 {
     JournalDateView *entry = nullptr;
     if (mEntries.contains(dt)) {
@@ -143,7 +142,7 @@ void JournalView::showIncidences(const Akonadi::Item::List &incidences, const QD
     Q_UNUSED(date)
     clearEntries();
     for (const Akonadi::Item &i : incidences) {
-        if (const KCalendarCore::Journal::Ptr j = CalendarSupport::journal(i)) {
+        if (const KCalendarCore::Journal::Ptr j = Akonadi::CalendarUtils::journal(i)) {
             appendJournal(i, j->dtStart().date());
         }
     }
@@ -151,7 +150,7 @@ void JournalView::showIncidences(const Akonadi::Item::List &incidences, const QD
 
 void JournalView::changeIncidenceDisplay(const Akonadi::Item &incidence, Akonadi::IncidenceChanger::ChangeType changeType)
 {
-    if (KCalendarCore::Journal::Ptr journal = CalendarSupport::journal(incidence)) {
+    if (KCalendarCore::Journal::Ptr journal = Akonadi::CalendarUtils::journal(incidence)) {
         switch (changeType) {
         case Akonadi::IncidenceChanger::ChangeTypeCreate:
             appendJournal(incidence, journal->dtStart().date());
